==> charlatan_0.2.0.tar.gz: charlatan/R/lorem-provider-ja_JP.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/lorem/ja_JP/__init__.py

lorem_word_connector_ja_jp <- ''
lorem_sentence_punctuation_ja_jp <- '\\u3002'
lorem_word_list_ja_jp <- c(
  "\u30b3\u30df\u30e5\u30cb\u30c6\u30a3",
  "\u96a0\u3059",
  "\u8449",
  "\u9676\u5668",
  "\u932f\u899a",
  "\u30d0\u30fc\u30b2\u30f3",
  "\u30ea\u30cb\u30a2",
  "\u30b3\u30fc\u30e9\u30b9",
  "\u4ed5\u4e0a\u3052",
  "\u53d4\u7236",
  "\u79fb\u52d5",
  "\u5dee\u5225\u3059\u308b",
  "\u6975\u7aef\u306a",
  "\u6570\u5b57",
  "\u30c6\u30f3\u30c8",
  "\u5fc5\u8981",
  "\u4e3b\u4eba",
  "\u96fb\u6c60",
  "\u30bd\u30fc\u30b9",
  "\u91ce\u7403",
  "\u30b9\u30c8\u30ec\u30fc\u30b8",
  "\u30b9\u30ad\u30fc\u30e0",
  "\u6696\u304b\u3044",
  "\u3055\u3055\u3084\u304d",
  "\u5668\u5b98",
  "\u30c8\u30ea\u30d3\u30e5\u30fc\u30c8",
  "\u540c\u884c",
  "\u30b8\u30e3\u30e0",
  "\u30d1\u30f3",
  "\u7d22\u5f15",
  "\u30c8\u30b9",
  "\u7e54\u308b",
  "\u30d1\u30fc\u30bb\u30f3\u30c8",
  "\u62e1\u5f35",
  "\u6559\u6388",
  "\u30d0\u30b9\u30b1\u30c3\u30c8",
  "\u5275\u50b7",
  "\u30d5\u30ec\u30fc\u30e0",
  "\u660e\u3089\u304b\u306b\u3059\u308b",
  "\u30d5\u30a7\u30df\u30cb\u30b9\u30c8",
  "\u767a\u751f\u3059\u308b",
  "\u6012\u308a",
  "\u30dc\u30c8\u30eb",
  "\u72d0",
  "\u67d4\u3089\u304b\u3044",
  "\u30ea\u30d5\u30c8",
  "\u30d0\u30b9",
  "\u96ea",
  "\u753b\u9762",
  "\u30d1\u30a4\u30aa\u30cb\u30a2",
  "\u30de\u30ea\u30f3",
  "\u30c0\u30a4\u30e4\u30e2\u30f3\u30c9",
  "\u666e\u901a\u306e",
  "\u610f\u56f3",
  "\u30d8\u30a2",
  "\u65e5\u66dc\u65e5",
  "\u30d7\u30e9\u30b9\u30c1\u30c3\u30af",
  "\u885d\u7a81",
  "\u8a55\u8b70\u4f1a",
  "\u4e3b\u5a66",
  "\u4fdd\u8a3c\u91d1",
  "\u52d5\u7269",
  "\u53c2\u52a0\u3059\u308b",
  "\u6559\u4f1a",
  "\u30b3\u30df\u30e5\u30cb\u30b1\u30fc\u30b7\u30e7\u30f3",
  "\u61b2\u6cd5",
  "\u672c\u8cea\u7684\u306a",
  "\u63a2\u67fb",
  "\u547c\u3076",
  "\u4f9b\u7d66",
  "\u30b9\u30da\u30eb",
  "\u518d\u73fe\u3059\u308b",
  "\u5408\u8a08",
  "\u30c0\u30c3\u30b7\u30e5",
  "\u64c1\u3059\u308b",
  "\u77e5\u899a",
  "\u30b7\u30a7\u30fc\u30d3\u30f3\u30b0",
  "\u30b3\u30f3\u30da",
  "\u30aa\u30fc\u30af\u30b7\u30e7\u30f3",
  "\u7d30\u304b\u3044",
  "\u30cb\u30e5\u30fc\u30b9",
  "\u764c",
  "\u30c8\u30fc\u30f3",
  "\u30c1\u30fc\u30ba",
  "\u53cd\u5c04",
  "\u30d6\u30e9\u30f3\u30c1",
  "\u30b3\u30d4\u30fc",
  "\u72b6\u6cc1",
  "\u30b9\u30de\u30c3\u30b7\u30e5",
  "\u5f0f",
  "\u5354\u529b",
  "\u7ba1\u7406\u3059\u308b",
  "\u6587\u8a00",
  "\u7de8\u7d44",
  "\u30b8\u30e3\u30fc\u30ca\u30eb",
  "\u8150\u3063\u305f",
  "\u898b\u843d\u3068\u3059",
  "\u30cf\u30fc\u30c9\u30a6\u30a7\u30a2",
  "\u30d4\u30c3\u30af",
  "\u611f\u8b1d\u3059\u308b",
  "\u697d\u3057\u3093\u3067",
  "\u4eba\u5f62",
  "\u5efa\u7bc9",
  "\u898b\u51fa\u3057",
  "\u30bf\u30ef\u30fc",
  "\u30db\u30a4\u30fc\u30eb",
  "\u7701\u7565",
  "\u30ed\u30b0",
  "\u52a9\u3051\u3066",
  "\u4e0d\u81ea\u7136\u306a",
  "\u51fa\u6f14\u8005",
  "\u8ee2\u5012",
  "\u904b",
  "\u969c\u5bb3",
  "\u30af\u30eb\u30fc",
  "\u8ffd\u653e\u3059\u308b",
  "\u6708",
  "\u30ab\u30ec\u30c3\u30b8",
  "\u7de9\u3080",
  "\u5206\u5272",
  "\u6b20\u4e4f",
  "\u901a\u884c\u6599\u91d1",
  "\u96fb\u8a71",
  "\u72ed\u3044",
  "\u4e2d\u592e",
  "\u57cb\u3081\u8fbc\u3080",
  "\u9769\u65b0",
  "\u30d6\u30ec\u30fc\u30ad",
  "\u30b3\u30fc\u30ca\u30fc",
  "\u6e9d",
  "\u810a\u690e",
  "\u30d6\u30e9\u30b1\u30c3\u30c8",
  "\u6226\u7565\u7684",
  "\u5c3f",
  "\u8840\u307e\u307f\u308c\u306e",
  "\u5c0a\u656c\u3059\u308b",
  "\u50ac\u7720\u8853",
  "\u30a2\u30af\u30bb\u30eb\u30da\u30c0\u30eb",
  "\u53b3\u3057\u3044",
  "\u30b5\u30f3\u30d7\u30eb",
  "\u5968\u52b1\u3057\u307e\u3059",
  "\u6307\u540d",
  "\u30af\u30fc\u30eb",
  "\u30af\u30ed\u30b9",
  "\u30d2\u30fc\u30eb",
  "\u6575\u5bfe\u7684\u306a",
  "\u8fd1\u4ee3\u5316\u3059\u308b",
  "\u90e8\u968a",
  "\u76ee\u7684",
  "\u4fdd\u6301\u3059\u308b",
  "\u4e2d\u4e16",
  "\u30c7\u30c3\u30c9",
  "\u30ce\u30fc\u30c8",
  "\u30c7\u30d5\u30a9\u30eb\u30c8",
  "\u72af\u7f6a\u8005",
  "\u30ad\u30e3\u30d3\u30f3",
  "\u526f",
  "\u6539\u5584",
  "\u8077\u4eba",
  "\u30b7\u30e5\u30ac\u30fc",
  "\u82b1\u5ac1",
  "\u502b\u7406",
  "\u504f\u5dee",
  "\u8ca9\u58f2",
  "\u8ef8",
  "\u30b5\u30e9\u30c0",
  "\u54c1\u8cea",
  "\u98a8\u666f",
  "\u8650\u5f85",
  "\u7acb\u6d3e\u306a",
  "\u30d9\u30eb\u30d9\u30c3\u30c8",
  "\u30cf\u30f3\u30de\u30fc",
  "\u30ad\u30e3\u30d3\u30cd\u30c3\u30c8",
  "\u30c8\u30ec\u30fc\u30ca\u30fc",
  "\u30ea\u30cf\u30d3\u30ea",
  "\u30b5\u30ef\u30fc",
  "\u9023\u7d9a",
  "\u5b66\u751f",
  "\u9ad8\u3044",
  "\u8cde\u8cdb\u3059\u308b",
  "\u884c\u9032",
  "\u30c0\u30cb",
  "\u8a3c\u8a00\u3059\u308b",
  "\u7b26\u53f7",
  "\u30d0\u30ca\u30fc",
  "\u30d0\u30b1\u30c4",
  "\u30ab\u30e9\u30e0",
  "\u88c5\u7f6e",
  "\u30d2\u30c3\u30c8",
  "\u6575",
  "\u30c8\u30fc\u30b9\u30c8",
  "\u8a66\u3057\u3066\u307f\u308b",
  "\u5927\u7d71\u9818",
  "\u5c4b\u6839\u88cf",
  "\u30e1\u30cb\u30e5\u30fc",
  "\u6b8b\u308b",
  "\u30ea\u30f3\u30af",
  "\u8217\u88c5",
  "\u30a4\u30f3\u30c1",
  "\u7279\u5fb4",
  "\u306f",
  "\u6301\u3064",
  "\u6301\u3063\u3066\u3044\u307e\u3057\u305f",
  "\u3042\u3063\u305f",
  "\u301c",
  "\u306a\u3044",
  "\u4eca",
  "\u4eca\u65e5",
  "\u6301\u3063\u3066\u308b",
  "\u5348\u524d",
  "\u79c1",
  "\u541b\u306f",
  "\u5f7c",
  "\u5f7c\u5973",
  "\u305d\u308c",
  "\u81ea\u4f53",
  "\u3042\u306a\u305f\u81ea\u8eab",
  "\u3058\u3076\u3093\u306e",
  "\u9271\u5c71"
)

==> charlatan_0.5.1.tar.gz: charlatan/R/lorem-provider-ja_JP.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/lorem/ja_JP/__init__.py

lorem_word_connector_ja_jp <- ""
lorem_sentence_punctuation_ja_jp <- "\\u3002"
lorem_word_list_ja_jp <- c(
  "\u30b3\u30df\u30e5\u30cb\u30c6\u30a3",
  "\u96a0\u3059",
  "\u8449",
  "\u9676\u5668",
  "\u932f\u899a",
  "\u30d0\u30fc\u30b2\u30f3",
  "\u30ea\u30cb\u30a2",
  "\u30b3\u30fc\u30e9\u30b9",
  "\u4ed5\u4e0a\u3052",
  "\u53d4\u7236",
  "\u79fb\u52d5",
  "\u5dee\u5225\u3059\u308b",
  "\u6975\u7aef\u306a",
  "\u6570\u5b57",
  "\u30c6\u30f3\u30c8",
  "\u5fc5\u8981",
  "\u4e3b\u4eba",
  "\u96fb\u6c60",
  "\u30bd\u30fc\u30b9",
  "\u91ce\u7403",
  "\u30b9\u30c8\u30ec\u30fc\u30b8",
  "\u30b9\u30ad\u30fc\u30e0",
  "\u6696\u304b\u3044",
  "\u3055\u3055\u3084\u304d",
  "\u5668\u5b98",
  "\u30c8\u30ea\u30d3\u30e5\u30fc\u30c8",
  "\u540c\u884c",
  "\u30b8\u30e3\u30e0",
  "\u30d1\u30f3",
  "\u7d22\u5f15",
  "\u30c8\u30b9",
  "\u7e54\u308b",
  "\u30d1\u30fc\u30bb\u30f3\u30c8",
  "\u62e1\u5f35",
  "\u6559\u6388",
  "\u30d0\u30b9\u30b1\u30c3\u30c8",
  "\u5275\u50b7",
  "\u30d5\u30ec\u30fc\u30e0",
  "\u660e\u3089\u304b\u306b\u3059\u308b",
  "\u30d5\u30a7\u30df\u30cb\u30b9\u30c8",
  "\u767a\u751f\u3059\u308b",
  "\u6012\u308a",
  "\u30dc\u30c8\u30eb",
  "\u72d0",
  "\u67d4\u3089\u304b\u3044",
  "\u30ea\u30d5\u30c8",
  "\u30d0\u30b9",
  "\u96ea",
  "\u753b\u9762",
  "\u30d1\u30a4\u30aa\u30cb\u30a2",
  "\u30de\u30ea\u30f3",
  "\u30c0\u30a4\u30e4\u30e2\u30f3\u30c9",
  "\u666e\u901a\u306e",
  "\u610f\u56f3",
  "\u30d8\u30a2",
  "\u65e5\u66dc\u65e5",
  "\u30d7\u30e9\u30b9\u30c1\u30c3\u30af",
  "\u885d\u7a81",
  "\u8a55\u8b70\u4f1a",
  "\u4e3b\u5a66",
  "\u4fdd\u8a3c\u91d1",
  "\u52d5\u7269",
  "\u53c2\u52a0\u3059\u308b",
  "\u6559\u4f1a",
  "\u30b3\u30df\u30e5\u30cb\u30b1\u30fc\u30b7\u30e7\u30f3",
  "\u61b2\u6cd5",
  "\u672c\u8cea\u7684\u306a",
  "\u63a2\u67fb",
  "\u547c\u3076",
  "\u4f9b\u7d66",
  "\u30b9\u30da\u30eb",
  "\u518d\u73fe\u3059\u308b",
  "\u5408\u8a08",
  "\u30c0\u30c3\u30b7\u30e5",
  "\u64c1\u3059\u308b",
  "\u77e5\u899a",
  "\u30b7\u30a7\u30fc\u30d3\u30f3\u30b0",
  "\u30b3\u30f3\u30da",
  "\u30aa\u30fc\u30af\u30b7\u30e7\u30f3",
  "\u7d30\u304b\u3044",
  "\u30cb\u30e5\u30fc\u30b9",
  "\u764c",
  "\u30c8\u30fc\u30f3",
  "\u30c1\u30fc\u30ba",
  "\u53cd\u5c04",
  "\u30d6\u30e9\u30f3\u30c1",
  "\u30b3\u30d4\u30fc",
  "\u72b6\u6cc1",
  "\u30b9\u30de\u30c3\u30b7\u30e5",
  "\u5f0f",
  "\u5354\u529b",
  "\u7ba1\u7406\u3059\u308b",
  "\u6587\u8a00",
  "\u7de8\u7d44",
  "\u30b8\u30e3\u30fc\u30ca\u30eb",
  "\u8150\u3063\u305f",
  "\u898b\u843d\u3068\u3059",
  "\u30cf\u30fc\u30c9\u30a6\u30a7\u30a2",
  "\u30d4\u30c3\u30af",
  "\u611f\u8b1d\u3059\u308b",
  "\u697d\u3057\u3093\u3067",
  "\u4eba\u5f62",
  "\u5efa\u7bc9",
  "\u898b\u51fa\u3057",
  "\u30bf\u30ef\u30fc",
  "\u30db\u30a4\u30fc\u30eb",
  "\u7701\u7565",
  "\u30ed\u30b0",
  "\u52a9\u3051\u3066",
  "\u4e0d\u81ea\u7136\u306a",
  "\u51fa\u6f14\u8005",
  "\u8ee2\u5012",
  "\u904b",
  "\u969c\u5bb3",
  "\u30af\u30eb\u30fc",
  "\u8ffd\u653e\u3059\u308b",
  "\u6708",
  "\u30ab\u30ec\u30c3\u30b8",
  "\u7de9\u3080",
  "\u5206\u5272",
  "\u6b20\u4e4f",
  "\u901a\u884c\u6599\u91d1",
  "\u96fb\u8a71",
  "\u72ed\u3044",
  "\u4e2d\u592e",
  "\u57cb\u3081\u8fbc\u3080",
  "\u9769\u65b0",
  "\u30d6\u30ec\u30fc\u30ad",
  "\u30b3\u30fc\u30ca\u30fc",
  "\u6e9d",
  "\u810a\u690e",
  "\u30d6\u30e9\u30b1\u30c3\u30c8",
  "\u6226\u7565\u7684",
  "\u5c3f",
  "\u8840\u307e\u307f\u308c\u306e",
  "\u5c0a\u656c\u3059\u308b",
  "\u50ac\u7720\u8853",
  "\u30a2\u30af\u30bb\u30eb\u30da\u30c0\u30eb",
  "\u53b3\u3057\u3044",
  "\u30b5\u30f3\u30d7\u30eb",
  "\u5968\u52b1\u3057\u307e\u3059",
  "\u6307\u540d",
  "\u30af\u30fc\u30eb",
  "\u30af\u30ed\u30b9",
  "\u30d2\u30fc\u30eb",
  "\u6575\u5bfe\u7684\u306a",
  "\u8fd1\u4ee3\u5316\u3059\u308b",
  "\u90e8\u968a",
  "\u76ee\u7684",
  "\u4fdd\u6301\u3059\u308b",
  "\u4e2d\u4e16",
  "\u30c7\u30c3\u30c9",
  "\u30ce\u30fc\u30c8",
  "\u30c7\u30d5\u30a9\u30eb\u30c8",
  "\u72af\u7f6a\u8005",
  "\u30ad\u30e3\u30d3\u30f3",
  "\u526f",
  "\u6539\u5584",
  "\u8077\u4eba",
  "\u30b7\u30e5\u30ac\u30fc",
  "\u82b1\u5ac1",
  "\u502b\u7406",
  "\u504f\u5dee",
  "\u8ca9\u58f2",
  "\u8ef8",
  "\u30b5\u30e9\u30c0",
  "\u54c1\u8cea",
  "\u98a8\u666f",
  "\u8650\u5f85",
  "\u7acb\u6d3e\u306a",
  "\u30d9\u30eb\u30d9\u30c3\u30c8",
  "\u30cf\u30f3\u30de\u30fc",
  "\u30ad\u30e3\u30d3\u30cd\u30c3\u30c8",
  "\u30c8\u30ec\u30fc\u30ca\u30fc",
  "\u30ea\u30cf\u30d3\u30ea",
  "\u30b5\u30ef\u30fc",
  "\u9023\u7d9a",
  "\u5b66\u751f",
  "\u9ad8\u3044",
  "\u8cde\u8cdb\u3059\u308b",
  "\u884c\u9032",
  "\u30c0\u30cb",
  "\u8a3c\u8a00\u3059\u308b",
  "\u7b26\u53f7",
  "\u30d0\u30ca\u30fc",
  "\u30d0\u30b1\u30c4",
  "\u30ab\u30e9\u30e0",
  "\u88c5\u7f6e",
  "\u30d2\u30c3\u30c8",
  "\u6575",
  "\u30c8\u30fc\u30b9\u30c8",
  "\u8a66\u3057\u3066\u307f\u308b",
  "\u5927\u7d71\u9818",
  "\u5c4b\u6839\u88cf",
  "\u30e1\u30cb\u30e5\u30fc",
  "\u6b8b\u308b",
  "\u30ea\u30f3\u30af",
  "\u8217\u88c5",
  "\u30a4\u30f3\u30c1",
  "\u7279\u5fb4",
  "\u306f",
  "\u6301\u3064",
  "\u6301\u3063\u3066\u3044\u307e\u3057\u305f",
  "\u3042\u3063\u305f",
  "\u301c",
  "\u306a\u3044",
  "\u4eca",
  "\u4eca\u65e5",
  "\u6301\u3063\u3066\u308b",
  "\u5348\u524d",
  "\u79c1",
  "\u541b\u306f",
  "\u5f7c",
  "\u5f7c\u5973",
  "\u305d\u308c",
  "\u81ea\u4f53",
  "\u3042\u306a\u305f\u81ea\u8eab",
  "\u3058\u3076\u3093\u306e",
  "\u9271\u5c71"
)
